@@ -18,6 +18,7 @@ Plots the analysis obtained in causal impact algorithm.
 """
 
 
+import numpy as np
 import pandas as pd
 
 
@@ -26,7 +27,8 @@ def plot(
     pre_data: pd.DataFrame,
     post_data: pd.DataFrame,
     panels=['original', 'pointwise', 'cumulative'],
-    figsize=(10, 7)
+    figsize=(10, 7),
+    show=True
 ) -> None:
     """Plots inferences results related to causal impact analysis.
 
@@ -36,7 +38,12 @@ def plot(
         Indicates which plot should be considered in the graphics.
       figsize: tuple.
         Changes the size of the graphics plotted.
-
+      show: bool.
+        If true, runs plt.show(), i.e., displays the figure.
+        If false, it gives acess to the axis, i.e., the figure can be saved
+        and the style of the plot can be modified by getting the axis with
+        `ax = plt.gca()` or the figure with `fig = plt.gcf()`.
+        Defaults to True.
     Raises
     ------
       RuntimeError: if inferences were not computed yet.
@@ -51,7 +58,9 @@ def plot(
                     panel, ', '.join(['"{}"'.format(e) for e in valid_panels])
                 )
             )
+    pre_data, post_data, inferences = build_data(pre_data, post_data, inferences)
     pre_post_index = pre_data.index.union(post_data.index)
+
     post_period_init = post_data.index[0]
     intervention_idx = pre_post_index.get_loc(post_period_init)
     n_panels = len(panels)
@@ -132,7 +141,32 @@ def plot(
         ax.axhline(y=0, color='gray', linestyle='--')
         ax.legend()
         ax.grid(True, color='gainsboro')
-    plt.show()
+    if show:
+        plt.show()
+
+
+def build_data(
+    pre_data: pd.DataFrame,
+    post_data: pd.DataFrame,
+    inferences: pd.DataFrame
+) -> [pd.DataFrame, pd.DataFrame, pd.DataFrame]:
+    """
+    Input data may contain NaN points due TFP requirement for a valid frequency set. As
+    it breaks the plotting API this function removes those points.
+    """
+    if isinstance(inferences.index, pd.RangeIndex):
+        pre_data = pre_data.set_index(pd.RangeIndex(start=0, stop=len(pre_data)))
+        post_data = post_data.set_index(pd.RangeIndex(start=len(pre_data),
+                                        stop=len(pre_data) + len(post_data)))
+    pre_data_null_index = pre_data[pre_data.iloc[:, 0].isnull()].index
+    post_data_null_index = post_data[post_data.iloc[:, 0].isnull()].index
+
+    pre_data = pre_data.drop(pre_data_null_index).astype(np.float64)
+    post_data = post_data.drop(post_data_null_index).astype(np.float64)
+    inferences = inferences.drop(
+        pre_data_null_index.union(post_data_null_index)
+    ).astype(np.float64)
+    return pre_data, post_data, inferences
 
 
 def get_plotter():  # pragma: no cover
